@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1302,7 +1302,7 @@ class CLineGraphDraw extends CGraphDraw {
 	 *
 	 * @return array
 	 */
-	private function getOptimalDateTimeIntervalSpec(int $pref_sub_interval, float $min_sub_interval): array {
+	private function getOptimalDateTimeIntervalSpec($pref_sub_interval, $min_sub_interval) {
 		// Possible X-axis main and sub-intervals.
 		$intervals = [
 			'PT1M' => ['PT1S', 'PT5S', 'PT10S', 'PT30S'],
@@ -1382,7 +1382,7 @@ class CLineGraphDraw extends CGraphDraw {
 	 *
 	 * @return array
 	 */
-	private function getDateTimeIntervals(int $start, int $end, DateInterval $interval): array {
+	private function getDateTimeIntervals($start, $end, $interval) {
 		$intervals = [];
 
 		$interval_ts = (new DateTime('@0'))
