@@ -51,20 +51,20 @@ function getLocales() {
 	return [
 		'en_GB' => ['name' => _('English (en_GB)'),	'display' => true],
 		'en_US' => ['name' => _('English (en_US)'),	'display' => true],
-		'bg_BG' => ['name' => _('Bulgarian (bg_BG)'),	'display' => false],
+		'bg_BG' => ['name' => _('Bulgarian (bg_BG)'),	'display' => true],
 		'ca_ES' => ['name' => _('Catalan (ca_ES)'),	'display' => false],
 		'zh_CN' => ['name' => _('Chinese (zh_CN)'),	'display' => true],
-		'zh_TW' => ['name' => _('Chinese (zh_TW)'),	'display' => false],
+		'zh_TW' => ['name' => _('Chinese (zh_TW)'),	'display' => true],
 		'cs_CZ' => ['name' => _('Czech (cs_CZ)'),	'display' => true],
 		'nl_NL' => ['name' => _('Dutch (nl_NL)'),	'display' => false],
 		'fi_FI' => ['name' => _('Finnish (fi_FI)'),	'display' => false],
 		'fr_FR' => ['name' => _('French (fr_FR)'),	'display' => true],
 		'ka_GE' => ['name' => _('Georgian (ka_GE)'),	'display' => false],
-		'de_DE' => ['name' => _('German (de_DE)'),	'display' => false],
-		'el_GR' => ['name' => _('Greek (el_GR)'),	'display' => false],
+		'de_DE' => ['name' => _('German (de_DE)'),	'display' => true],
+		'el_GR' => ['name' => _('Greek (el_GR)'),	'display' => true],
 		'he_IL' => ['name' => _('Hebrew (he_IL)'),	'display' => true],
 		'hu_HU' => ['name' => _('Hungarian (hu_HU)'),	'display' => false],
-		'id_ID' => ['name' => _('Indonesian (id_ID)'),	'display' => false],
+		'id_ID' => ['name' => _('Indonesian (id_ID)'),	'display' => true],
 		'it_IT' => ['name' => _('Italian (it_IT)'),	'display' => true],
 		'ko_KR' => ['name' => _('Korean (ko_KR)'),	'display' => true],
 		'ja_JP' => ['name' => _('Japanese (ja_JP)'),	'display' => true],
@@ -75,14 +75,14 @@ function getLocales() {
 		'pl_PL' => ['name' => _('Polish (pl_PL)'),	'display' => true],
 		'pt_BR' => ['name' => _('Portuguese (pt_BR)'),	'display' => true],
 		'pt_PT' => ['name' => _('Portuguese (pt_PT)'),	'display' => true],
-		'ro_RO' => ['name' => _('Romanian (ro_RO)'),	'display' => false],
+		'ro_RO' => ['name' => _('Romanian (ro_RO)'),	'display' => true],
 		'ru_RU' => ['name' => _('Russian (ru_RU)'),	'display' => true],
 		'sk_SK' => ['name' => _('Slovak (sk_SK)'),	'display' => true],
-		'es_ES' => ['name' => _('Spanish (es_ES)'),	'display' => false],
+		'es_ES' => ['name' => _('Spanish (es_ES)'),	'display' => true],
 		'sv_SE' => ['name' => _('Swedish (sv_SE)'),	'display' => false],
 		'tr_TR' => ['name' => _('Turkish (tr_TR)'),	'display' => true],
 		'uk_UA' => ['name' => _('Ukrainian (uk_UA)'),	'display' => true],
-		'vi_VN' => ['name' => _('Vietnamese (vi_VN)'),	'display' => false]
+		'vi_VN' => ['name' => _('Vietnamese (vi_VN)'),	'display' => true]
 	];
 }
 
