@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,13 +20,6 @@
 #ifndef ZABBIX_JSON_PARSER_H
 #define ZABBIX_JSON_PARSER_H
 
-#define SKIP_WHITESPACE(src)	\
-	while ('\0' != *(src) && NULL != strchr(ZBX_WHITESPACE, *(src))) (src)++
-
-#define SKIP_WHITESPACE_NEXT(src)\
-	(src)++; \
-	SKIP_WHITESPACE(src)
-
 int	zbx_json_validate(const char *start, char **error);
 
 int	json_parse_value(const char *start, char **error);
