@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #include "sysinfo.h"
 #include "zbxjson.h"
 #include "log.h"
+#include "zbxalgo.h"
+#include "inodes.h"
 
 static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *free,
 		zbx_uint64_t *used, double *pfree, double *pused, char **error)
@@ -37,6 +39,7 @@ static int	get_fs_size_stat(const char *fs, zbx_uint64_t *total, zbx_uint64_t *f
 	if (0 != ZBX_STATFS(fs, &s))
 	{
 		*error = zbx_dsprintf(NULL, "Cannot obtain filesystem information: %s", zbx_strerror(errno));
+		zabbix_log(LOG_LEVEL_DEBUG,"%s failed with error: %s",__func__, *error);
 		return SYSINFO_RET_FAIL;
 	}
 
@@ -214,8 +217,8 @@ int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 	while (NULL != (mt = getmntent(f)))
 	{
 		zbx_json_addobject(&j, NULL);
-		zbx_json_addstring(&j, "{#FSNAME}", mt->mnt_dir, ZBX_JSON_TYPE_STRING);
-		zbx_json_addstring(&j, "{#FSTYPE}", mt->mnt_type, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&j, ZBX_LLD_MACRO_FSNAME, mt->mnt_dir, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&j, ZBX_LLD_MACRO_FSTYPE, mt->mnt_type, ZBX_JSON_TYPE_STRING);
 		zbx_json_close(&j);
 	}
 
@@ -229,3 +232,123 @@ int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	return SYSINFO_RET_OK;
 }
+
+static int	vfs_fs_get(AGENT_REQUEST *request, AGENT_RESULT *result)
+{
+	struct mntent		*mt;
+	FILE			*f;
+	struct zbx_json		j;
+	zbx_uint64_t		total, not_used, used;
+	zbx_uint64_t		itotal, inot_used, iused;
+	double			pfree, pused;
+	double			ipfree, ipused;
+	char 			*error;
+	zbx_vector_ptr_t	mntpoints;
+	zbx_mpoint_t		*mntpoint;
+	char 			*mpoint;
+	int			ret = SYSINFO_RET_FAIL;
+
+	/* opening the mounted filesystems file */
+	if (NULL == (f = setmntent(MNT_MNTTAB, "r")))
+	{
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot obtain system information: %s", zbx_strerror(errno)));
+		return SYSINFO_RET_FAIL;
+	}
+
+	zbx_vector_ptr_create(&mntpoints);
+
+	/* fill mnttab structure from file */
+	while (NULL != (mt = getmntent(f)))
+	{
+		mpoint = mt->mnt_dir;
+		if (SYSINFO_RET_OK != get_fs_size_stat(mpoint, &total, &not_used, &used, &pfree, &pused, &error))
+		{
+			zbx_free(error);
+			continue;
+		}
+		if (SYSINFO_RET_OK != get_fs_inode_stat(mpoint, &itotal, &inot_used, &iused, &ipfree, &ipused, "pused",
+				&error))
+		{
+			zbx_free(error);
+			continue;
+		}
+
+		mntpoint = (zbx_mpoint_t *)zbx_malloc(NULL, sizeof(zbx_mpoint_t));
+		zbx_strlcpy(mntpoint->fsname, mpoint, MAX_STRING_LEN);
+		zbx_strlcpy(mntpoint->fstype, mt->mnt_type, MAX_STRING_LEN);
+		mntpoint->bytes.total = total;
+		mntpoint->bytes.used = used;
+		mntpoint->bytes.not_used = not_used;
+		mntpoint->bytes.pfree = pfree;
+		mntpoint->bytes.pused = pused;
+		mntpoint->inodes.total = itotal;
+		mntpoint->inodes.used = iused;
+		mntpoint->inodes.not_used = inot_used;
+		mntpoint->inodes.pfree = ipfree;
+		mntpoint->inodes.pused = ipused;
+
+		zbx_vector_ptr_append(&mntpoints, mntpoint);
+	}
+
+	endmntent(f);
+
+	if (NULL == (f = setmntent(MNT_MNTTAB, "r")))
+	{
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot obtain system information: %s", zbx_strerror(errno)));
+		goto out;
+	}
+
+	zbx_json_initarray(&j, ZBX_JSON_STAT_BUF_LEN);
+
+	while (NULL != (mt = getmntent(f)))
+	{
+		int idx;
+
+		mpoint = mt->mnt_dir;
+
+		if (FAIL != (idx = zbx_vector_ptr_search(&mntpoints, mpoint, ZBX_DEFAULT_STR_COMPARE_FUNC)))
+		{
+			mntpoint = (zbx_mpoint_t *)mntpoints.values[idx];
+			zbx_json_addobject(&j, NULL);
+			zbx_json_addstring(&j, ZBX_SYSINFO_TAG_FSNAME, mntpoint->fsname, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&j, ZBX_SYSINFO_TAG_FSTYPE, mntpoint->fstype, ZBX_JSON_TYPE_STRING);
+			zbx_json_addobject(&j, ZBX_SYSINFO_TAG_BYTES);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_TOTAL, mntpoint->bytes.total);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_FREE, mntpoint->bytes.not_used);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_USED, mntpoint->bytes.used);
+			zbx_json_addfloat(&j, ZBX_SYSINFO_TAG_PFREE, mntpoint->bytes.pfree);
+			zbx_json_addfloat(&j, ZBX_SYSINFO_TAG_PUSED, mntpoint->bytes.pused);
+			zbx_json_close(&j);
+			zbx_json_addobject(&j, ZBX_SYSINFO_TAG_INODES);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_TOTAL, mntpoint->inodes.total);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_FREE, mntpoint->inodes.not_used);
+			zbx_json_adduint64(&j, ZBX_SYSINFO_TAG_USED, mntpoint->inodes.used);
+			zbx_json_addfloat(&j, ZBX_SYSINFO_TAG_PFREE, mntpoint->inodes.pfree);
+			zbx_json_addfloat(&j, ZBX_SYSINFO_TAG_PUSED, mntpoint->inodes.pused);
+			zbx_json_close(&j);
+			zbx_json_close(&j);
+		}
+	}
+
+	endmntent(f);
+
+	zbx_json_close(&j);
+
+	SET_STR_RESULT(result, zbx_strdup(NULL, j.buffer));
+
+	zbx_json_free(&j);
+
+	ret = SYSINFO_RET_OK;
+out:
+	zbx_vector_ptr_clear_ext(&mntpoints, (zbx_clean_func_t)zbx_mpoints_free);
+	zbx_vector_ptr_destroy(&mntpoints);
+
+	return ret;
+}
+
+int	VFS_FS_GET(AGENT_REQUEST *request, AGENT_RESULT *result)
+{
+	return zbx_execute_threaded_metric(vfs_fs_get, request, result);
+
+}
+
