@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -304,6 +304,12 @@ int	init_perf_collector(zbx_threadedness_t threadedness, char **error)
 
 	ppsd.nextcheck = time(NULL) + UNSUPPORTED_REFRESH_PERIOD;
 
+	if (SUCCEED != init_builtin_counter_indexes())
+	{
+		*error = zbx_strdup(*error, "cannot initialize built-in counter indexes");
+		goto out;
+	}
+
 	ret = SUCCEED;
 out:
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
